@@ -2,41 +2,7 @@ package Vimana::Logger;
 use strict;
 use warnings;
 
-if (eval {
-        require Log::Log4perl;
-        Log::Log4perl->import(':levels');
-        1;
-    } ) {
-    my $level = lc($ENV{VIMANA_LOGLEVEL} || "info");
-    $level = { map { $_ => uc $_ } qw( debug info warn error fatal ) }
-        ->{ $level } || 'INFO';
-
-    my $conf_file = $ENV{VIMANA_LOGCONFFILE};
-    my $conf;
-    if ( defined($conf_file) and -e $conf_file ) {
-        my $fh;
-        open $fh, $conf_file or die $!;
-        local $/;
-        $conf = <$fh>;
-        close $fh;
-    }
-    #warn $conf unless $Log::Log4perl::Logger::INITIALIZED;
-    $conf ||= qq{
-        log4perl.rootLogger=$level, Screen
-        log4perl.appender.Screen = Log::Log4perl::Appender::Screen
-        log4perl.appender.Screen.stderr = 0
-        log4perl.appender.Screen.layout = PatternLayout
-        log4perl.appender.Screen.layout.ConversionPattern = %m%n
-    };
-
-    # ... passed as a reference to init()
-    Log::Log4perl::init( \$conf ) unless Log::Log4perl->initialized;
-    *get_logger = sub { Log::Log4perl->get_logger(@_) };
-}
-else {
-    *get_logger = sub { 'Vimana::Logger::Compat' };
-}
-
+*get_logger = sub { 'Vimana::Logger::Compat' };
 
 sub import {
   my $class = shift;
@@ -96,6 +62,9 @@ BEGIN {
 
 1;
 __END__
+
+=encoding utf8
+
 =head1 NAME
 
 Vimana::Logger - logging framework for Vimana
